==> haskell-bytestring-strict-builder-0.4.5.1-15-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-bytestring-strict-builder.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: bytestring-strict-builder
version: 0.4.5.1
id: bytestring-strict-builder-0.4.5.1-1BBET5jx2iJFeMpN3FXFmF
key: bytestring-strict-builder-0.4.5.1-1BBET5jx2iJFeMpN3FXFmF
license: MIT
copyright: (c) 2017, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
author: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/bytestring-strict-builder
synopsis: An efficient strict bytestring builder
description:
    According to
    <https://github.com/nikita-volkov/bytestring-builders-benchmark the competition benchmarks>,
    this library provides on average the fastest builder of strict bytestrings.
    .
    Practical benchmarks have proven it to be highly performant as well.
    The encoders from the \"postgresql-binary\" library have shown
    a stable performance improvement by factors of up to 10 after the migration
    from the standard builder to \"bytestring-strict-builder\".
category: Text, ByteString, Builders, Serialization
abi: e0d7d1648963f9634479b899b6139515
exposed: True
exposed-modules:
    ByteString.StrictBuilder
hidden-modules: ByteString.StrictBuilder.Prelude
                ByteString.StrictBuilder.Population
                ByteString.StrictBuilder.Population.UncheckedShifting
                ByteString.StrictBuilder.UTF8
import-dirs: /usr/lib/ghc-8.4.3/site-local/bytestring-strict-builder-0.4.5.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/bytestring-strict-builder-0.4.5.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/bytestring-strict-builder-0.4.5.1
hs-libraries: HSbytestring-strict-builder-0.4.5.1-1BBET5jx2iJFeMpN3FXFmF
depends:
    bytestring-0.10.8.2 base-prelude-1.3-6USA4MwBClb3KaEhnb0gD7
    base-4.11.1.0
abi-depends: bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             base-prelude-1.3-6USA4MwBClb3KaEhnb0gD7=9396e903f9c3781aaf5fd627a604df05
             base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
haddock-interfaces: /usr/share/doc/haskell-bytestring-strict-builder/html/bytestring-strict-builder.haddock
haddock-html: /usr/share/doc/haskell-bytestring-strict-builder/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-bytestring-strict-builder-0.4.5.1-20-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-bytestring-strict-builder.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: bytestring-strict-builder
version: 0.4.5.1
id: bytestring-strict-builder-0.4.5.1-TZooXNIMo4KH25cfF6Qmr
key: bytestring-strict-builder-0.4.5.1-TZooXNIMo4KH25cfF6Qmr
license: MIT
copyright: (c) 2017, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
author: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/bytestring-strict-builder
synopsis: An efficient strict bytestring builder
description:
    According to
    <https://github.com/nikita-volkov/bytestring-builders-benchmark the competition benchmarks>,
    this library provides on average the fastest builder of strict bytestrings.
    .
    Practical benchmarks have proven it to be highly performant as well.
    The encoders from the \"postgresql-binary\" library have shown
    a stable performance improvement by factors of up to 10 after the migration
    from the standard builder to \"bytestring-strict-builder\".
category: Text, ByteString, Builders, Serialization
abi: 944857ce8851b6ad21e751ecfea9b0ad
exposed: True
exposed-modules:
    ByteString.StrictBuilder
hidden-modules: ByteString.StrictBuilder.Prelude
                ByteString.StrictBuilder.Population
                ByteString.StrictBuilder.Population.UncheckedShifting
                ByteString.StrictBuilder.UTF8
import-dirs: /usr/lib/ghc-8.4.3/site-local/bytestring-strict-builder-0.4.5.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/bytestring-strict-builder-0.4.5.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/bytestring-strict-builder-0.4.5.1
hs-libraries: HSbytestring-strict-builder-0.4.5.1-TZooXNIMo4KH25cfF6Qmr
depends:
    bytestring-0.10.8.2 base-prelude-1.3-6USA4MwBClb3KaEhnb0gD7
    base-4.11.1.0
abi-depends: bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             base-prelude-1.3-6USA4MwBClb3KaEhnb0gD7=9396e903f9c3781aaf5fd627a604df05
             base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
haddock-interfaces: /usr/share/doc/haskell-bytestring-strict-builder/html/bytestring-strict-builder.haddock
haddock-html: /usr/share/doc/haskell-bytestring-strict-builder/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
